OC.L10N.register(
    "core",
    {
    "Please select a file." : "Prosím, vyberte súbor.",
    "File is too big" : "Súbor je príliš veľký",
    "The selected file is not an image." : "Vybraný súbor nie je obrázok.",
    "The selected file cannot be read." : "Vybraný súbor nie je možné čítať.",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor bol nahraný iba čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
    "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
    "Invalid file provided" : "Zadaný neplatný súbor",
    "No image or file provided" : "Obrázok alebo súbor nebol zadaný",
    "Unknown filetype" : "Neznámy typ súboru",
    "An error occurred. Please contact your admin." : "Vyskytla sa chyba.\nProsím, kontaktujte svojho správcu.\n\t",
    "Invalid image" : "Chybný obrázok",
    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
    "No crop data provided" : "Dáta pre orezanie neboli zadané",
    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
    "Crop is not square" : "Orezanie nie je štvorcové",
    "State token does not match" : "Príznak stavu nesúhlasí",
    "Invalid app password" : "Neplatné heslo aplikácie",
    "Could not complete login" : "Nie je možné dokončiť prihlásenie",
    "State token missing" : "Chýba stavový token",
    "Your login token is invalid or has expired" : "Váš prihlasovací token je neplatný alebo jeho platnosť skončila",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitné vydanie Nextcloud nie je podporované a push upozornenia nie sú k dispozícii.",
    "Login" : "Prihlásiť sa",
    "Unsupported email length (>255)" : "Dĺžka emailovej správy nie je podporovaná (>255)",
    "Password reset is disabled" : "Obnovenie hesla nie je povolené",
    "Could not reset password because the token is expired" : "Nepodarilo sa obnoviť heslo, pretože platnosť tokenu uplynula",
    "Could not reset password because the token is invalid" : "Nepodarilo sa obnoviť heslo, pretože token nie je platný",
    "Password is too long. Maximum allowed length is 469 characters." : "Heslo je príliš dlhé. Maximálna povolená dĺžka je 469 znakov.",
    "%s password reset" : "reset hesla %s",
    "Password reset" : "Obnovenie hesla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúce tlačidlo. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúci odkaz. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
    "Reset your password" : "Vytvoriť nové heslo",
    "The given provider is not available" : "Zadaný poskytovateľ nie je dostupný",
    "Task not found" : "Úloha nebola nájdená",
    "Internal error" : "Interná chyba",
    "Not found" : "Nenájdené",
    "Bad request" : "Neplatná požiadavka",
    "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
    "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
    "No text to image provider is available" : "Nie je dostupný žiadny poskytovateľ služby \"text na obrázok\"",
    "Image not found" : "Obrázok nenájdený",
    "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
    "Could not detect language" : "Nepodarilo sa zistiť jazyk",
    "Unable to translate" : "Nie je možné preložiť",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Niektoré odkazy so sprístupnením boli odstránené.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre sprístupnenie. Pre viac informácií nasledujte tento link.",
    "The account limit of this instance is reached." : "Limit pre počet užívateľov pre túto inštanciu bol dosiahnutý.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Zadajte svoj kľúč predplatného v aplikácii podpory, aby ste zvýšili limit pre množstvo účtov. To vám tiež poskytuje všetky ďalšie výhody, ktoré Nextcloud Enterprise ponúka a je vysoko odporúčaný pre prevádzku vo firemnom prostredí.",
    "Learn more ↗" : "Viac informácií ↗",
    "Preparing update" : "Pripravuje sa aktualizácia",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Krok opravy:",
    "Repair info:" : "Informácie o oprave:",
    "Repair warning:" : "Varovanie o oprave:",
    "Repair error:" : "Chyba opravy:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Prosím, použite aktualizáciu z príkazového riadka, pretože aktualizácia cez prehliadač je zakázaná vo vašom config.php.",
    "Turned on maintenance mode" : "Mód údržby je zapnutý",
    "Turned off maintenance mode" : "Mód údržby je vypnutý",
    "Maintenance mode is kept active" : "Režim údržby je stále aktívny",
    "Updating database schema" : "Aktualizuje sa schéma databázy",
    "Updated database" : "Databáza je aktualizovaná",
    "Update app \"%s\" from App Store" : "Aktualizovať aplikáciu \"%s\" z obchodu",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontroluje sa, či je možné aktualizovať schému databázy pre %s (to môže trvať dlhší čas v závislosti na veľkosti databázy)",
    "Updated \"%1$s\" to %2$s" : "Aktualizované \"%1$s\" na %2$s",
    "Set log level to debug" : "Nastaviť úroveň záznamu na ladenie",
    "Reset log level" : "Obnoviť úroveň záznamu",
    "Starting code integrity check" : "Začína kontrola integrity kódu",
    "Finished code integrity check" : "Kontrola integrity kódu ukončená",
    "%s (incompatible)" : "%s (nekompatibilná)",
    "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
    "Already up to date" : "Už aktuálne",
    "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
    "unknown text" : "neznámy text",
    "Hello world!" : "Ahoj svet!",
    "sunny" : "slnečno",
    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
    "Hello {name}" : "Vitaj {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
    "new" : "nový",
    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
    "Update to {version}" : "Aktualizuj na {version}",
    "An error occurred." : "Vyskytla sa chyba.",
    "Please reload the page." : "Obnovte prosím stránku.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
    "Continue to {productName}" : "Pokračovať na {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
    "Applications menu" : "Ponuka aplikácií",
    "Apps" : "Aplikácie",
    "More apps" : "Viac aplikácií",
    "_{count} notification_::_{count} notifications_" : ["{count} upozornenie","{count} upozornenia","{count} upozornení","{count} upozornenia"],
    "No" : "Nie",
    "Yes" : "Áno",
    "Federated user" : "Združený užívateľ",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Vytvoriť sprístupnenie",
    "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud zlyhalo",
    "Custom date range" : "Vlastné rozpätie dátumov",
    "Pick start date" : "Vyberte dátum začiatku",
    "Pick end date" : "Vyberte dátum ukončenia",
    "Search in date range" : "Hľadať v rozsahu dátumov",
    "Search in current app" : "Hľadať v aktuálnej aplikácii",
    "Clear search" : "Vymazať hľadanie",
    "Search everywhere" : "Hľadať všade",
    "Unified search" : "Jednotné vyhľadávanie",
    "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
    "Places" : "Miesta",
    "Date" : "Dátum",
    "Today" : "Dnes",
    "Last 7 days" : "Posledných 7 dní",
    "Last 30 days" : "Posledných 30 dní",
    "This year" : "Tento rok",
    "Last year" : "Minulý rok",
    "Search people" : "Hľadať ľudí",
    "People" : "Ľudia",
    "Filter in current view" : "Filter v aktuálnom zobrazení",
    "Results" : "Výsledky",
    "Load more results" : "Načítať viac výsledkov",
    "Search in" : "Hľadať v",
    "Searching …" : "Hľadá sa…",
    "Start typing to search" : "Začnite písať pre vyhľadanie",
    "No matching results" : "Žiadne zhodujúce výsledky",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Medzi ${this.dateFilter.startFrom.toLocaleDateString()} a ${this.dateFilter.endAt.toLocaleDateString()}",
    "Log in" : "Prihlásiť sa",
    "Logging in …" : "Prihlasujem ...",
    "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
    "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
    "Temporary error" : "Dočasná chyba",
    "Please try again." : "Prosím skúste to znova.",
    "An internal error occurred." : "Došlo k vnútornej chybe.",
    "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
    "Password" : "Heslo",
    "Log in to {productName}" : "Prihlásiť sa do {productName}u",
    "Wrong login or password." : "Nesprávne meno alebo heslo.",
    "This account is disabled" : "Tento účet je deaktivovaný",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
    "Account name or email" : "Názov účtu alebo e-mail",
    "Account name" : "Názov účtu",
    "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
    "Login or email" : "Prihlasovacie meno alebo email",
    "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
    "Browser not supported" : "Prehliadač nie je podporovaný",
    "Passwordless authentication is not supported in your browser." : "Bezheslové overovanie nie je vo vašom prehliadači podporované.",
    "Your connection is not secure" : "Pripojenie nie je bezpečné",
    "Passwordless authentication is only available over a secure connection." : "Bezheslové overovanie je dostupné len pomocou šifrovaného pripojenia.",
    "Reset password" : "Obnovenie hesla",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ak tento účet existuje, na jeho e-mailovú adresu bola odoslaná správa pre obnovenie hesla. Ak ju nedostanete, overte si svoju e-mailovú adresu a/alebo Login, skontrolujte svoje spam/junk priečinky alebo požiadajte o pomoc miestneho administrátora.",
    "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
    "Password cannot be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
    "Back to login" : "Späť na prihlásenie",
    "New password" : "Nové heslo",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše súbory sú šifrované. Po obnovení hesla nebude možné dostať sa k vašim údajom. Ak neviete, čo robíte, kontaktujte vášho administrátora a až potom pokračujte. Naozaj chcete pokračovať?",
    "I know what I'm doing" : "Viem, čo robím",
    "Resetting password" : "Obnovuje sa heslo",
    "Recommended apps" : "Odporúčané apky",
    "Loading apps …" : "Načítavanie apiek...",
    "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
    "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
    "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
    "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
    "Skip" : "Preskočiť",
    "Installing apps …" : "Inštalácia apiek...",
    "Install recommended apps" : "Nainštalovať odporúčané apky",
    "Schedule work & meetings, synced with all your devices." : "Naplánujte si prácu a stretnutia, synchronizované so všetkými vašimi zariadeniami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Udržujte si údaje o svojich kolegoch a priateľoch na jednom mieste bez hrozby úniku ich súkromných informácií tretím stranám.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednoduchá apka pre čítanie e-mailov, prepojená so Súbormi, Kontaktami a Kalendárom.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
    "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
    "Settings menu" : "Menu nastavení",
    "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
    "Search contacts" : "Prehľadať kontakty",
    "Reset search" : "Vynuluj vyhľadávanie",
    "Search contacts …" : "Prehľadať kontakty...",
    "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
    "No contacts found" : "Kontakty nenájdené",
    "Show all contacts" : "Zobraziť všetky kontakty",
    "Install the Contacts app" : "Inštalovať aplikáciu Kontakty",
    "Loading your contacts …" : "Načítavam vaše kontakty...",
    "Looking for {term} …" : "Hľadá sa výraz {term}...",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
    "Search for {name} only" : "Hľadať iba {name}",
    "Loading more results …" : "Načítava sa viac výsledkov …",
    "Search" : "Hľadať",
    "No results for {query}" : "Žiadne výsledky pre {query}",
    "Press Enter to start searching" : "Stlačte Enter pre spustenie hľadania",
    "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
    "Forgot password?" : "Zabudli ste heslo?",
    "Back to login form" : "Späť na prihlásenie",
    "Back" : "Späť",
    "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
    "Edit Profile" : "Upraviť rofil",
    "The headline and about sections will show up here" : "Tu sa zobrazí titul a sekcia Informácie",
    "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
    "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
    "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
    "More actions" : "Viac akcií",
    "This browser is not supported" : "Tento prehliadač nie je podporovaný",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
    "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
    "Supported versions" : "Podporované verzie",
    "{name} version {version} and above" : "{name} verzie {version} alebo vyššej",
    "Search {types} …" : "Vyhľadať {types}",
    "Choose {file}" : "Vyberte {file}",
    "Choose" : "Vybrať",
    "Copy to {target}" : "Kopírovať do {target}",
    "Copy" : "Kopírovať",
    "Move to {target}" : "Presunúť do {target}",
    "Move" : "Presunúť",
    "OK" : "OK",
    "read-only" : "iba na čítanie",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt súboru","{count} konflikty súboru","{count} konfliktov súboru","{count} konfliktov súboru"],
    "One file conflict" : "Jeden konflikt súboru",
    "New Files" : "Nové súbory",
    "Already existing files" : "Už existujúce súbory",
    "Which files do you want to keep?" : "Ktoré súbory chcete ponechať?",
    "If you select both versions, the copied file will have a number added to its name." : "Ak zvolíte obe verzie, názov nakopírovaného súboru bude doplnený o číslo.",
    "Cancel" : "Zrušiť",
    "Continue" : "Pokračovať",
    "(all selected)" : "(všetko vybrané)",
    "({count} selected)" : "({count} vybraných)",
    "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
    "Saving …" : "Ukladá sa...",
    "seconds ago" : "pred sekundami",
    "Connection to server lost" : "Stratené spojenie so serverom",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
    "Add to a project" : "Pridať do projektu",
    "Show details" : "Zobraziť podrobnosti",
    "Hide details" : "Skryť podrobnosti",
    "Rename project" : "Premenovať projekt",
    "Failed to rename the project" : "Nepodarilo sa premenovať projekt",
    "Failed to create a project" : "Nepodarilo sa vytvoriť projekt",
    "Failed to add the item to the project" : "Nepodarilo sa pridať položku do projektu",
    "Connect items to a project to make them easier to find" : "Priradiť položky do projektu, aby sa ľahšie hľadali",
    "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
    "New in" : "Nové v",
    "View changelog" : "Zobraziť súhrn zmien",
    "Very weak password" : "Veľmi slabé heslo",
    "Weak password" : "Slabé heslo",
    "So-so password" : "Priemerné heslo",
    "Good password" : "Dobré heslo",
    "Strong password" : "Silné heslo",
    "No action available" : "NIe sú dostupné žiadne akcie",
    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
    "Close \"{dialogTitle}\" dialog" : "Zatvoriť okno \"{dialogTitle}\"",
    "Email length is at max (255)" : "E-mailová správa má maximálnu veľkosť (255)",
    "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľný",
    "Delete" : "Zmazať",
    "Rename" : "Premenovať",
    "Collaborative tags" : "Štítky pre spoluprácu",
    "No tags found" : "Štítky sa nenašli",
    "Personal" : "Osobné",
    "Accounts" : "Účty",
    "Admin" : "Administrácia",
    "Help" : "Pomoc",
    "Access forbidden" : "Prístup odmietnutý",
    "Profile not found" : "Profil nenájdený",
    "The profile does not exist." : "Profil neexistuje.",
    "Back to %s" : "Späť na %s",
    "Page not found" : "Stránka nenájdená",
    "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
    "Too many requests" : "Priveľa požiadavok",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
    "Error" : "Chyba",
    "Internal Server Error" : "Vnútorná chyba servera",
    "The server was unable to complete your request." : "Server nebol schopný dokončiť vašu žiadosť.",
    "If this happens again, please send the technical details below to the server administrator." : "Ak sa to stane opäť, nižšie zašlite technické podrobnosti správcovi servera.",
    "More details can be found in the server log." : "Viac nájdete v logu servera.",
    "For more details see the documentation ↗." : "Viac podrobností nájdete vdokumentácii ↗.",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Správa: %s",
    "File: %s" : "Súbor: %s",
    "Line: %s" : "Riadok: %s",
    "Trace" : "Trasa",
    "Security warning" : "Bezpečnostné varovanie",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
    "Create an <strong>admin account</strong>" : "Vytvoriť <strong>administrátorský účet</strong>",
    "Show password" : "Zobraziť heslo",
    "Toggle password visibility" : "Prepnúť viditeľnosť hesla",
    "Storage & database" : "Úložisko & databáza",
    "Data folder" : "Priečinok dát",
    "Configure the database" : "Nastaviť databázu",
    "Only %s is available." : "Je dostupný len %s.",
    "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
    "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
    "Database account" : "Databázový účet",
    "Database password" : "Heslo databázy",
    "Database name" : "Meno databázy",
    "Database tablespace" : "Tabuľkový priestor databázy",
    "Database host" : "Server databázy",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
    "Performance warning" : "Varovanie o výkone",
    "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
    "Install" : "Inštalovať",
    "Installing …" : "Inštalujem ...",
    "Need help?" : "Potrebujete pomoc?",
    "See the documentation" : "Pozri dokumentáciu",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vyzerá, že sa snažíte preinštalovať svoj Nextcloud. Avšak v priečinku s konfiguráciou chýba súbor CAN_INSTALL. Ak chcete pokračovať, tak ho vytvorte.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie je možné odstrániť súbor CAN_INSTALL z priečinka s konfiguráciou. Je potrebné ho odstrániť ručne.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Táto aplikácia vyžaduje JavaScript, aby správne fungovala. Prosím, {linkstart}zapnite si JavaScript{linkend} a obnovte stránku",
    "Skip to main content" : "Prejsť na hlavný obsah",
    "Skip to navigation of app" : "Preskočiť do navigácie apky",
    "Go to %s" : "Prejsť na %s",
    "Get your own free account" : "Získajte zdarma svoj vlastný účet",
    "Connect to your account" : "Pripojte sa k svojmu účtu",
    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
    "App password" : "Heslo aplikácie",
    "Grant access" : "Povoliť prístup",
    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
    "Account access" : "Prístup k účtu",
    "Currently logged in as %1$s (%2$s)." : "Momentálne prihlásený ako %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
    "Account connected" : "Účet pripojený",
    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
    "You can close this window." : "Toto okno už môžete zatvoriť.",
    "Previous" : "Predchádzajúce",
    "This share is password-protected" : "Toto sprístupnenie je chránené heslom",
    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
    "Email address" : "E-mailová adresa",
    "Password sent!" : "Heslo odoslané!",
    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
    "Two-factor authentication" : "Dvojfázové overovanie",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načítať minimálne jeden z vašich povolených spôsobov na dvojfázové overovanie. Kontaktujte prosím správcu systému.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Kontaktujte administrátora pre ďalšiu asistenciu.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Vo vašom účte sa vynucuje dvojfázové overovanie, ale ešte nebolo nakonfigurované. Pokračujte prosím do nastavenia dvojfázového overovania.",
    "Set up two-factor authentication" : "Nastaviť dvojfázové overovanie",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dvojfaktorová autentifikácia je vyžadovaná ale nebola nakonfigurovaná pre Váš účet.  Použite jeden zo záložných kódov na prihlásenie alebo kontaktujte administrátora pre ďalšiu asistenciu.",
    "Use backup code" : "Použiť záložný kód",
    "Cancel login" : "Zruš prihlasovanie",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Pre váš účet je vynútená zvýšená bezpečnosť. Vyberte si poskytovateľa, ktorého chcete nastaviť:",
    "Error while validating your second factor" : "Chyba počas overovania druhého faktora",
    "Access through untrusted domain" : "Prístup cez nedôveryhodnú doménu",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontaktujte svojho správcu. Ak ste administrátorom vy, upravte nastavenie \"trusted_domains\" v config/config.php ako napríklad v config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Viac informácií o konfigurácii je možné nájsť v %1$s dokumentácii %2$s.",
    "App update required" : "Je nutná aktualizácia aplikácie",
    "%1$s will be updated to version %2$s" : "%1$s bude zaktualizovaný na verziu %2$s.",
    "The following apps will be updated:" : "Aktualizujú sa nasledujúce aplikácie:",
    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
    "The theme %s has been disabled." : "Téma %s bola zakázaná.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
    "Start update" : "Spustiť aktualizáciu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
    "Detailed logs" : "Podrobné záznamy",
    "Update needed" : "Aktualizácia je potrebná",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 účtami.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pre pomoc si pozrite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentáciu</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Viem, že ak budem pokračovať v aktualizácii prostredníctvom webového rozhrania, existuje riziko, že žiadosť prekročí časový limit a môže spôsobiť stratu dát, ale mám zálohu a viem, ako obnoviť svoju inštanciu v prípade zlyhania.",
    "Upgrade via web on my own risk" : "Aktualizovať cez web na vlastné riziko",
    "Maintenance mode" : "Mód údržby",
    "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
    "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
    "The user limit of this instance is reached." : "Limit pre počet užívateľov pre túto inštanciu bol dosiahnutý.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Zadajte svoj kľúč predplatného v aplikácii podpory, aby ste zvýšili limit používateľov. To vám tiež poskytuje všetky ďalšie výhody, ktoré Nextcloud Enterprise ponúka a je vysoko odporúčaný pre prevádzku vo firemnom prostredí.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Váš webový server nie je zatiaľ správne nastavený, aby umožnil synchronizáciu súborov, pretože rozhranie WebDAV sa zdá byť nefunkčné.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Váš webový server nie je správne nastavený na spracovanie \"{url}\". Viac informácií môžete nájsť v {linkstart}dokumentácii ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Váš web server nie je správne nastavený, aby preložil \"{url}\". To pravdepodobne súvisí s nastavením webového servera, ktoré nebolo aktualizované pre priame doručovanie tohto priečinka. Porovnajte prosím svoje nastavenia voči dodávaným rewrite pravidlám v \".htaccess\" pre Apache alebo tým, ktoré uvádzame v {linkstart}dokumentácii ↗{linkend} pre Nginx. V Nginx je typicky potrebné aktualizovať riadky začínajúce na \"location ~\".",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Váš server nie je správne nastavený tak, aby doručoval súbory .woff2. Toto je typicky problém s nastavením Nginx. Pre Nextcloud 15 je potrebné ho upraviť, aby tieto súbory doručoval. Porovnajte nastavenie svojho Nginx s tým, ktorý je odporúčaný v našej {linkstart}dokumentácii ↗{linkend}.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "K svojej inštancii pristupujete cez zabezpečené pripojenie, avšak vaša inštancia generuje nezabezpečené adresy URL. To s najväčšou pravdepodobnosťou znamená, že ste za reverzným proxy serverom a konfiguračné premenné prepisu nie sú nastavené správne. Prečítajte si o tom {linkstart} stránku s dokumentáciou ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš dátový adresár a súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby k dátovému adresáru už nebol prístupný, alebo presunúť dátový adresár mimo koreňa dokumentov webového servera.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" neobsahuje \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie adekvátne upraviť.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Hlavička HTTP „{header}“ nie je nastavená na „{val1}“, „{val2}“, „{val3}“, „{val4}“ alebo „{val5}“. To môže spôsobiť únik referer informácie. Prečítajte si {linkstart} odporúčanie W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Hlavička HTTP „Strict-Transport-Security“ nie je nastavená na minimálne „{seconds}“ sekúnd. Kvôli zvýšenému zabezpečeniu sa odporúča povoliť HSTS, ako je popísané v {linkstart} bezpečnostných tipoch ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Prístup na stránku nezabezpečený cez HTTP. Dôrazne sa odporúča nastaviť váš server tak, aby namiesto toho vyžadoval HTTPS, ako je opísané v {linkstart}bezpečnostných tipoch ↗{linkend}. Bez toho niektoré dôležité webové funkcie, ako napríklad \"kopírovať do schránky\" alebo \"service workers\", nebudú fungovať!",
    "Currently open" : "V súčasnosti otvorené",
    "Wrong username or password." : "Nesprávne používateľské meno alebo heslo.",
    "User disabled" : "Používateľ zakázaný",
    "Login with username or email" : "Prihlásiť sa pomocou užívateľského mena alebo e-mailu",
    "Login with username" : "Prihlásiť sa s užívateľským menom",
    "Username or email" : "Používateľské meno alebo e-mail",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ak existuje tento účet, na jeho e-mailovú adresu bola odoslaná správa na obnovenie hesla. Ak ju nedostanete, overte si svoju e-mailovú adresu a/alebo názov účtu, skontrolujte svoje spam/junk priečinky alebo požiadajte o pomoc miestneho administrátora.",
    "Apps and Settings" : "Aplikácie a Nastavenia",
    "Error loading message template: {error}" : "Chyba pri nahrávaní šablóny správy: {error}",
    "Users" : "Používatelia",
    "Username" : "Meno používateľa",
    "Database user" : "Používateľ databázy",
    "This action requires you to confirm your password" : "Táto akcia vyžaduje potvrdenie vášho hesla",
    "Confirm your password" : "Potvrďte svoje heslo",
    "Confirm" : "Potvrdiť",
    "App token" : "Token aplikácie",
    "Alternative log in using app token" : "Alternatívne prihlásenie pomocou tokenu aplikácie",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 používateľmi."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
